%if 0%{?el6}%{?el7}
    # python3 and python version related macros
    # required to build python3- subpackage
    # are not available in el6 and el7
    %global with_python3    0
    %global __python2       %{__python}
    %global python2_sitelib %{python_sitelib}
%else
    %bcond_without python3
%endif

%global         pkgname django-sekizai

Name:           python-%{pkgname}
Version:        0.8.1
Release:        8%{?dist}
Summary:        Django Template Blocks with extra functionality
Group:          Development/Libraries
License:        BSD
URL:            http://django-sekizai.readthedocs.org/
Source0:        https://pypi.python.org/packages/source/d/%{pkgname}/%{pkgname}-%{version}.tar.gz
Patch0:         django-1.8-compatibility.patch
Patch1:         django-sekizai-0.8.1-importlib.patch

BuildArch:      noarch

BuildRequires:  python-sphinx
BuildRequires:  python2-devel
BuildRequires:  python-setuptools
%if 0%{?with_python3}
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
%endif

Requires:       python-django-classy-tags >= 0.3.1
Provides:       %{pkgname} = %{version}-%{release}

%description
Sekizai means “blocks” in Japanese, and that’s what this app provides.
A fresh look at blocks. With django-sekizai you can define placeholders
where your blocks get rendered and at different places in your templates
append to those blocks. This is especially useful for css and javascript.
Your sub-templates can now define css and Javascript files to be included,
and the css will be nicely put at the top and the Javascript to the bottom,
just like you should. Also sekizai will ignore any duplicate content
in a single block.

%package doc
Summary:        Documentation for %{pkgname}
Group:          Documentation
Requires:       %{name} = %{version}-%{release}
Provides:       %{pkgname}-docs = %{version}-%{release}

%description doc
This package contains the documentation for %{pkgname}.

%if 0%{?with_python3}
%package -n python3-%{pkgname}
Summary:        The easy-to-use and developer-friendly CMS
Group:          Development/Libraries
Requires:       python3-django-classy-tags >= 0.3.1
Provides:       %{pkgname} = %{version}-%{release}

%description -n python3-%{pkgname}
Sekizai means “blocks” in Japanese, and that’s what this app provides.
A fresh look at blocks. With django-sekizai you can define placeholders
where your blocks get rendered and at different places in your templates
append to those blocks. This is especially useful for css and javascript.
Your sub-templates can now define css and Javascript files to be included,
and the css will be nicely put at the top and the Javascript to the bottom,
just like you should. Also sekizai will ignore any duplicate content
in a single block.

%package -n python3-%{pkgname}-doc
Summary:        Documentation for %{pkgname}
Group:          Documentation
Requires:       python3-%{pkgname} = %{version}-%{release}
Provides:       %{pkgname}-docs = %{version}-%{release}

%description -n python3-%{pkgname}-doc
This package contains the documentation for %{pkgname}.
%endif


%prep
%setup -q -n %{pkgname}-%{version}
%patch0 -p 1
%patch1 -p 1

%if 0%{?with_python3}
cp -a . %{py3dir}
%endif


%build
%{__python2} setup.py build

%if 0%{?with_python3}
pushd %{py3dir}
%{__python3} setup.py build
popd
%endif

# build documentation
pushd docs
    make html
    rm _build/html/.buildinfo
popd


%install
%{__python2} setup.py install --skip-build --root %{buildroot}

%if 0%{?with_python3}
pushd %{py3dir}
%{__python3} setup.py install --skip-build --root %{buildroot}
popd
%endif

# create file list
(cd %{buildroot}; find *) | sed -r 's/\.py[co]?$/.py*/' | sort -u | \
while read FILE; do
    [ -d "%{buildroot}/$FILE" ] && echo "%dir /$FILE" || echo "/$FILE"
done > %{pkgname}.files

# separate Python 2 and Python 3 files
grep %{python2_sitelib}  %{pkgname}.files > python2-%{pkgname}.files
%if 0%{?with_python3}
grep %{python3_sitelib} %{pkgname}.files > python3-%{pkgname}.files
%endif


%files
%doc LICENSE README.rst
%dir %{python2_sitelib}/sekizai
%{python2_sitelib}/sekizai/*.py
%{python2_sitelib}/sekizai/*.py[co]
%dir %{python2_sitelib}/sekizai/templatetags
%{python2_sitelib}/sekizai/templatetags/*.py
%{python2_sitelib}/sekizai/templatetags/*.py[co]
%dir %{python2_sitelib}/sekizai/test_templates
%{python2_sitelib}/sekizai/test_templates/*.html
%dir %{python2_sitelib}/sekizai/test_templates/errors
%{python2_sitelib}/sekizai/test_templates/errors/*.html
%dir %{python2_sitelib}/sekizai/test_templates/inherit
%{python2_sitelib}/sekizai/test_templates/inherit/*.html
%dir %{python2_sitelib}/sekizai/test_templates/processors
%{python2_sitelib}/sekizai/test_templates/processors/*.html
%{python2_sitelib}/django_sekizai-%{version}-py2.*.egg-info


%files doc
%doc docs/_build/html

%if 0%{?with_python3}
%files -n python3-%{pkgname}
%doc LICENSE README.rst
%dir %{python3_sitelib}/sekizai
%{python3_sitelib}/sekizai/*.py
%dir %{python3_sitelib}/sekizai/__pycache__
%{python3_sitelib}/sekizai/__pycache__/*.py[co]
%dir %{python3_sitelib}/sekizai/templatetags
%{python3_sitelib}/sekizai/templatetags/*.py
%dir %{python3_sitelib}/sekizai/templatetags/__pycache__
%{python3_sitelib}/sekizai/templatetags/__pycache__/*.py[co]
%dir %{python3_sitelib}/sekizai/test_templates
%{python3_sitelib}/sekizai/test_templates/*.html
%dir %{python3_sitelib}/sekizai/test_templates/errors
%{python3_sitelib}/sekizai/test_templates/errors/*.html
%dir %{python3_sitelib}/sekizai/test_templates/inherit
%{python3_sitelib}/sekizai/test_templates/inherit/*.html
%dir %{python3_sitelib}/sekizai/test_templates/processors
%{python3_sitelib}/sekizai/test_templates/processors/*.html
%{python3_sitelib}/django_sekizai-%{version}-py3.*.egg-info

%files -n python3-%{pkgname}-doc
%doc docs/_build/html
%endif

%changelog
* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.8.1-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Mon Dec 19 2016 Miro Hrončok <mhroncok@redhat.com> - 0.8.1-7
- Rebuild for Python 3.6

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8.1-6
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.8.1-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Tue Nov 10 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8.1-4
- Rebuilt for https://fedoraproject.org/wiki/Changes/python3.5

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Thu Jun 11 2015 Jakub Dorňák <jdornak@redhat.com> - 0.8.1-2
- use importlib from python-libs instead of deprecated django.utils.importlib
  Resolves: #1230700

* Tue Jun  9 2015 Jakub Dorňák <jdornak@redhat.com> - 0.8.1-1
- Update to 0.8.1, django 1.8 compatibility

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.7-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Wed May 28 2014 Kalev Lember <kalevlember@gmail.com> - 0.7-2
- Rebuilt for https://fedoraproject.org/wiki/Changes/Python_3.4

* Mon Nov 25 2013 Jakub Dorňák <jdornak@redhat.com> - 0.7-1
- Initial package
